@@ -13,6 +13,10 @@ def _tf_convert(x: Any) -> tf.Tensor:
     return tf.convert_to_tensor(x, dtype=tf.float32)
 
 
+def _tf_cast_to_int(x: tf.Tensor) -> tf.Tensor:
+    return tf.cast(x, dtype=tf.int32)
+
+
 def _tf_round_to_int(x: tf.Tensor) -> tf.Tensor:
     return tf.cast(tf.math.rint(x), dtype=tf.int32)
 
@@ -40,7 +44,7 @@ def _tf_resize_image(
         dest_size: Tuple[int, int]
 ) -> tf.Tensor:
     """
-    dest_size: (height, width)
+    dest_size: (image_height, image_width)
     """
     return tf.image.resize(
         image, size=dest_size, method=tf.image.ResizeMethod.AREA
