@@ -9,7 +9,6 @@ from typing import Any, Callable, List, Optional, Sequence, Tuple, TypeVar
 import numpy as np  # type: ignore
 import tensorflow as tf  # type: ignore
 
-
 from targetran._check import (
     _check_shear_input,
     _check_translate_input,
@@ -18,6 +17,7 @@ from targetran._check import (
 )
 from targetran._tf_functional import (
     _tf_convert,
+    _tf_cast_to_int,
     _tf_round_to_int,
     _tf_resize_image,
     _tf_pad_image,
@@ -41,6 +41,7 @@ from targetran._transform import (
     _get_shear_mats,
     _get_translate_mats,
 )
+from targetran.utils import Interpolation
 
 T = TypeVar("T", np.ndarray, tf.Tensor)
 
@@ -99,9 +100,10 @@ def seqs_to_tf_dataset(
 def _tf_get_affine_dependency() -> _AffineDependency:
     return _AffineDependency(
         _tf_convert, tf.shape, tf.reshape, tf.expand_dims, tf.squeeze,
-        _tf_pad_image, tf.range, _tf_round_to_int, tf.repeat, tf.tile,
-        tf.ones_like, tf.stack, tf.concat, tf.matmul, tf.clip_by_value,
-        _tf_gather_image, tf.identity, tf.reduce_max, tf.reduce_min,
+        _tf_pad_image, tf.range, _tf_cast_to_int, _tf_round_to_int,
+        tf.repeat, tf.tile, tf.ones_like, tf.stack, tf.concat, tf.matmul,
+        tf.clip_by_value, tf.math.floor, tf.math.ceil, _tf_gather_image,
+        tf.identity, tf.reduce_max, tf.reduce_min,
         tf.logical_and, tf.boolean_mask
     )
 
@@ -111,11 +113,12 @@ def _tf_affine_transform(
         bboxes: tf.Tensor,
         labels: tf.Tensor,
         image_dest_tran_mat: tf.Tensor,
-        bboxes_tran_mat: tf.Tensor
+        bboxes_tran_mat: tf.Tensor,
+        interpolation: Interpolation
 ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
     return _affine_transform(
         image, bboxes, labels, image_dest_tran_mat, bboxes_tran_mat,
-        _tf_get_affine_dependency()
+        interpolation, _tf_get_affine_dependency()
     )
 
 
@@ -125,7 +128,8 @@ def tf_flip_left_right(
         labels: tf.Tensor
 ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
     return _flip_left_right(
-        image, bboxes, labels, _tf_get_affine_dependency()
+        image, bboxes, labels,
+        Interpolation.NEAREST, _tf_get_affine_dependency()
     )
 
 
@@ -135,7 +139,8 @@ def tf_flip_up_down(
         labels: tf.Tensor
 ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
     return _flip_up_down(
-        image, bboxes, labels, _tf_get_affine_dependency()
+        image, bboxes, labels,
+        Interpolation.NEAREST, _tf_get_affine_dependency()
     )
 
 
@@ -143,11 +148,12 @@ def tf_rotate(
         image: tf.Tensor,
         bboxes: tf.Tensor,
         labels: tf.Tensor,
-        angle_deg: float
+        angle_deg: float,
+        interpolation: Interpolation = Interpolation.BILINEAR
 ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
     return _rotate(
         image, bboxes, labels, _tf_convert(angle_deg), tf.cos, tf.sin,
-        _tf_get_affine_dependency()
+        interpolation, _tf_get_affine_dependency()
     )
 
 
@@ -156,13 +162,14 @@ def tf_shear(
         bboxes: tf.Tensor,
         labels: tf.Tensor,
         angle_deg: float,
-        check_input: bool = True
+        interpolation: Interpolation = Interpolation.BILINEAR,
+        _check_input: bool = True
 ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
-    if check_input:
+    if _check_input:
         _check_shear_input(angle_deg)
     return _shear(
         image, bboxes, labels, _tf_convert(angle_deg), tf.tan,
-        _tf_get_affine_dependency()
+        interpolation, _tf_get_affine_dependency()
     )
 
 
@@ -172,16 +179,17 @@ def tf_translate(
         labels: tf.Tensor,
         translate_height: int,
         translate_width: int,
-        check_input: bool = True
+        interpolation: Interpolation = Interpolation.BILINEAR,
+        _check_input: bool = True
 ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
-    if check_input:
+    if _check_input:
         _check_translate_input(
             image.get_shape(), translate_height, translate_width
         )
     return _translate(
         image, bboxes, labels,
         _tf_convert(translate_height), _tf_convert(translate_width),
-        _tf_get_affine_dependency()
+        interpolation, _tf_get_affine_dependency()
     )
 
 
@@ -206,9 +214,9 @@ def tf_crop(
         offset_width: int,
         crop_height: int,
         crop_width: int,
-        check_input: bool = True
+        _check_input: bool = True
 ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
-    if check_input:
+    if _check_input:
         _check_crop_input(image.get_shape(), offset_height, offset_width)
     return _crop(
         image, bboxes, labels,
@@ -304,6 +312,7 @@ class TFCombineAffine(TFRandomTransform):
             transforms: Sequence[TFRandomTransform],
             num_selected_transforms: Optional[int] = None,
             selected_probabilities: Optional[List[float]] = None,
+            interpolation: Interpolation = Interpolation.BILINEAR,
             probability: float = 1.0,
             seed: Optional[int] = None
     ) -> None:
@@ -325,6 +334,7 @@ class TFCombineAffine(TFRandomTransform):
         self._transforms = transforms
         self._num_selected_transforms = num_selected_transforms
         self._selected_probabilities = selected_probabilities
+        self._interpolation = interpolation
         self._identity_mat = tf.expand_dims(tf.constant([
             [1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]
         ]), axis=0)
@@ -378,7 +388,8 @@ class TFCombineAffine(TFRandomTransform):
             image, self._rand_fn
         )
         return super().__call__(
-            image, bboxes, labels, image_dest_tran_mat, bboxes_tran_mat
+            image, bboxes, labels, image_dest_tran_mat, bboxes_tran_mat,
+            self._interpolation
         )
 
 
@@ -445,12 +456,14 @@ class TFRandomRotate(TFRandomTransform):
     def __init__(
             self,
             angle_deg_range: Tuple[float, float] = (-15.0, 15.0),
+            interpolation: Interpolation = Interpolation.BILINEAR,
             probability: float = 0.9,
             seed: Optional[int] = None
     ) -> None:
         _check_input_range(angle_deg_range, None, "angle_deg_range")
         super().__init__(tf_rotate, probability, seed, "TFRandomRotate", True)
         self.angle_deg_range = angle_deg_range
+        self.interpolation = interpolation
 
     def _get_angle_deg(self, rand_fn: Callable[..., tf.Tensor]) -> tf.Tensor:
         return _tf_convert(self.angle_deg_range[1] - self.angle_deg_range[0]) \
@@ -474,7 +487,8 @@ class TFRandomRotate(TFRandomTransform):
             **kwargs: Any
     ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
         return super().__call__(
-            image, bboxes, labels, self._get_angle_deg(self._rand_fn)
+            image, bboxes, labels, self._get_angle_deg(self._rand_fn),
+            self.interpolation
         )
 
 
@@ -483,12 +497,14 @@ class TFRandomShear(TFRandomTransform):
     def __init__(
             self,
             angle_deg_range: Tuple[float, float] = (-10.0, 10.0),
+            interpolation: Interpolation = Interpolation.BILINEAR,
             probability: float = 0.9,
             seed: Optional[int] = None
     ) -> None:
         _check_input_range(angle_deg_range, (-90.0, 90.0), "angle_deg_range")
         super().__init__(tf_shear, probability, seed, "TFRandomShear", True)
         self.angle_deg_range = angle_deg_range
+        self.interpolation = interpolation
 
     def _get_angle_deg(self, rand_fn: Callable[..., tf.Tensor]) -> tf.Tensor:
         return _tf_convert(self.angle_deg_range[1] - self.angle_deg_range[0]) \
@@ -512,7 +528,8 @@ class TFRandomShear(TFRandomTransform):
             **kwargs: Any
     ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
         return super().__call__(
-            image, bboxes, labels, self._get_angle_deg(self._rand_fn), False
+            image, bboxes, labels, self._get_angle_deg(self._rand_fn),
+            self.interpolation, False
         )
 
 
@@ -522,6 +539,7 @@ class TFRandomTranslate(TFRandomTransform):
             self,
             translate_height_fraction_range: Tuple[float, float] = (-0.1, 0.1),
             translate_width_fraction_range: Tuple[float, float] = (-0.1, 0.1),
+            interpolation: Interpolation = Interpolation.BILINEAR,
             probability: float = 0.9,
             seed: Optional[int] = None
     ) -> None:
@@ -538,6 +556,7 @@ class TFRandomTranslate(TFRandomTransform):
         )
         self.translate_height_fraction_range = translate_height_fraction_range
         self.translate_width_fraction_range = translate_width_fraction_range
+        self.interpolation = interpolation
 
     def _get_translate_height_and_width(
             self,
@@ -575,7 +594,8 @@ class TFRandomTranslate(TFRandomTransform):
         translate_height, translate_width = \
             self._get_translate_height_and_width(image, self._rand_fn)
         return super().__call__(
-            image, bboxes, labels, translate_height, translate_width, False
+            image, bboxes, labels, translate_height, translate_width,
+            self.interpolation, False
         )
 
 
