@@ -2,11 +2,17 @@
 Utilities.
 """
 
+from enum import auto, Enum
 from typing import Any, Callable, Sequence, Tuple, TypeVar
 
 T = TypeVar("T")
 
 
+class Interpolation(Enum):
+    NEAREST = auto()
+    BILINEAR = auto()
+
+
 class Compose:
 
     def __init__(self, fns: Sequence[Callable[..., Any]]) -> None:
